@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
-# $Revision: 1.11 $ 
-# $Date: 2005/03/29 21:09:55 $
+# $Revision: 1.15 $
+# $Date: 2005/10/10 20:38:55 $
 # $Author: dwelch $
 #
 # (c) Copyright 2003-2004 Hewlett-Packard Development Company, L.P.
@@ -32,10 +32,10 @@
 
 string_table = {
 
-'unknown'   :       ( lambda : _( 'Unknown' ), 
+'unknown'   :       ( lambda : _( 'Unknown' ),
                       lambda : _( 'Unknown' ) ),
 
-'try_again' :       ( '', 
+'try_again' :       ( '',
                       lambda : _( 'Please correct the problem and try again.') ),
 
 'press_continue' :  ( '',
@@ -65,7 +65,7 @@ string_table = {
 '1005' :            ( lambda : _( 'Canceling.' ),
                       '' ),
 
-'1006' :            ( '%5002',
+'1006' :            ( '%5002%',
                       '%try_again%' ),
 
 '1007' :            ( lambda : _( 'Waiting for ink to dry.' ),
@@ -206,7 +206,10 @@ string_table = {
 '1507' :            ( lambda : _( 'Photo cyan cartridge is low on ink' ),
                                 '' ),
 
-'1509' :            ( lambda : _( 'Photo magenta cartridge is low on ink' ),
+'1508' :            ( lambda : _( 'Photo magenta cartridge is low on ink' ),
+                                '' ),
+
+'1509' :            ( lambda : _( 'Photo yellow cartridge is low on ink' ),
                                 '' ),
 
 '1510' :            ( lambda : _( 'Photo gray cartridge is low on ink' ),
@@ -248,13 +251,25 @@ string_table = {
 '1806' :            ( lambda : _( 'Service request.' ),
                       '%try_again%' ),
 
+'1900' :            ( lambda : _( 'Unsupported printer model.' ),
+                      '' ),
+
 '2000' :            ( lambda : _( 'Scan job started.' ),
                       '' ),
 
 '2001' :            ( lambda : _( 'Scan job completed.' ),
                       '' ),
 
-'2002' :            ( lambda : _( 'Scanner error.' ),
+'2002' :            ( lambda : _( 'Scan job failed.' ),
+                      '%try_again%' ),
+
+'3000' :            ( lambda : _( 'Fax job started.' ),
+                      '' ),
+
+'3001' :            ( lambda : _( 'Fax job complete.' ),
+                      '' ),
+
+'3002' :            ( lambda : _( 'Fax job failed.' ),
                       '%try_again%' ),
 
 '5002' :            ( lambda : _( 'Device is powered down or unplugged.' ),
@@ -285,10 +300,10 @@ string_table = {
                       '' ),
 
 '6002' :            ( lambda : _( 'Photocard unload failed.' ),
-                      lambda : _( 'Make sure photocard is inserted properly and try again.' ) ),   
+                      lambda : _( 'Make sure photocard is inserted properly and try again.' ) ),
 
 '6003' :            ( lambda : _( 'Unable to mount photocard on device.' ),
-                      '%6002%' ),   
+                      '%6002%' ),
 
 '6004' :            ( lambda : _( 'Photocard unloaded successfully.' ),
                       '' ),
@@ -325,7 +340,7 @@ string_table = {
 
 'agent_unknown_unknown' : ( '%unknown%',
                             '' ),
-                            
+
 'agent_unspecified_battery' : ( 'Battery',
                             '' ),
 
@@ -459,7 +474,7 @@ string_table = {
 
 'agent_unspecified_adf_kit'   : ( lambda : _('Document feeder (ADF) kit' ),
                                   '' ),
-                                  
+
 'agent_unspecified_drum_kit'   : ( lambda : _('Drum maintenance kit' ),
                                   '' ),
 
