@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
-# $Revision: 1.15 $
-# $Date: 2005/07/21 17:31:38 $
+# $Revision: 1.17 $
+# $Date: 2005/10/13 18:08:12 $
 # $Author: dwelch $
 #
 # (c) Copyright 2003-2005 Hewlett-Packard Development Company, L.P.
@@ -122,7 +122,11 @@ if not device_uri and not printer_name:
         log.error( "Error occured during interactive mode. Exiting." )
         sys.exit(0)
 
-d = device.Device( device_uri, printer_name )
+try:
+    d = device.Device( device_uri, printer_name )
+except Error, e:
+    log.error("Unable to open device: %s" % e.msg)
+    sys.exit(0)
 
 if d.device_uri is None and printer_name:
     log.error( "Printer '%s' not found." % printer_name )
@@ -143,7 +147,7 @@ log.info( "Performing type %d, level %d cleaning..." % ( clean_type, level ) )
 
 if clean_type in (CLEAN_TYPE_PCL,CLEAN_TYPE_PCL_WITH_PRINTOUT):
     if level == 3:
-        maint.wipeAndSpitType1()
+        maint.wipeAndSpitType1( d )
     elif level == 2:
         maint.primeType1( d )
     else:
