@@ -43,11 +43,9 @@ System::System()
    char buf[128];
 
    /* Set some defaults. */
-   HpiodPortNumber = 50000;
    DeviceCnt = 0;
    Reset = 0;
 
-   ReadConfig();
    pthread_mutex_init(&mutex, NULL); /* create fast mutex */
 
    for (i=0; i<MAX_DEVICE; i++)
@@ -72,11 +70,11 @@ System::System()
    sin.sin_family = AF_INET;
 //   sin.sin_addr.s_addr = INADDR_ANY;
    sin.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
-   sin.sin_port = htons(GetHpiodPortNumber());
+   sin.sin_port = htons(HpiodPortNumber);
 
    if (bind(Permsd, (struct sockaddr *)&sin, sizeof(sin)) == -1) 
    {
-      syslog(LOG_ERR, "unable to bind socket %d: %m\n", GetHpiodPortNumber());
+      syslog(LOG_ERR, "unable to bind socket %d: %m\n", HpiodPortNumber);
       exit(EXIT_FAILURE);
    }
 
@@ -87,21 +85,21 @@ System::System()
 
    if (listen(Permsd, 20) == -1) 
    {
-      syslog(LOG_ERR, "unable to listen socket %d: %m\n", GetHpiodPortNumber());
+      syslog(LOG_ERR, "unable to listen socket %d: %m\n", HpiodPortNumber);
       exit(EXIT_FAILURE);
    }
 
-   if((fd = open("/var/run/hpiod.port", O_CREAT | O_TRUNC | O_WRONLY, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH)) < 0)
+   if((fd = open(HpiodPortFile, O_CREAT | O_TRUNC | O_WRONLY, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH)) < 0)
    {
-      syslog(LOG_ERR, "unable create /var/run/hpiod.port: %m\n");
+      syslog(LOG_ERR, "unable create %s: %m\n", HpiodPortFile);
       exit(EXIT_FAILURE);
    }
 
-   len = sprintf(buf, "%d\n", GetHpiodPortNumber());
+   len = sprintf(buf, "%d\n", HpiodPortNumber);
    write(fd, buf, len);
    close(fd);
 
-   syslog(LOG_INFO, "%s accepting connections at %d...\n", VERSION, GetHpiodPortNumber()); 
+   syslog(LOG_INFO, "%s accepting connections at %d...\n", VERSION, HpiodPortNumber); 
 }
 
 System::~System()
@@ -120,37 +118,6 @@ System::~System()
    close(Permsd);
 }
 
-//System::ReadConfig
-//! Read changeable system parameters.
-/*!
-******************************************************************************/
-int System::ReadConfig()
-{
-   char rcbuf[LINE_SIZE]; /* Hold the value read */
-   char section[32];
-   FILE *inFile;
-   char *tail;
-        
-   if((inFile = fopen(RCFILE, "r")) == NULL) 
-   {
-      syslog(LOG_ERR, "unable to open %s: %m\n", RCFILE);
-      return 1;
-   } 
-
-   /* Read the config file */
-   while ((fgets(rcbuf, sizeof(rcbuf), inFile) != NULL))
-   {
-      if (rcbuf[0] == '[')
-         strncpy(section, rcbuf, sizeof(section)); /* found new section */
-      else if ((strncasecmp(section, "[hpiod]", 7) == 0) && (strncasecmp(rcbuf, "port=", 5) == 0))
-         HpiodPortNumber = strtol(rcbuf+5, &tail, 10);
-   }
-        
-   fclose(inFile);
-         
-   return 0;
-}
-
 //System::GetPair
 //!  Get key value pair from buffer. Assumes one key value pair per line.
 //!  Note, end-of-line '/n' is stripped out. Both key/value pairs are zero
@@ -332,14 +299,14 @@ int System::GetURIDataLink(char *uri, char *buf, int bufSize)
 
    buf[0] = 0;
 
-   if (strcasestr(uri, "hp:/usb") != NULL)
+   if (strcasestr(uri, ":/usb") != NULL)
    {
       if ((p = strcasestr(uri, "device=")) != NULL)
          p+=7;
       else
          return 0;
    }
-   else if (strcasestr(uri, "hp:/par") != NULL)
+   else if (strcasestr(uri, ":/par") != NULL)
    {
       if ((p = strcasestr(uri, "device=")) != NULL)
          p+=7;
@@ -445,7 +412,10 @@ int System::GeneralizeURI(MsgAttributes *ma)
    int i, len, found=0, result;
    Device *pD;
 
-   if (strcasestr(ma->uri, "hp:/usb") == NULL && strcasestr(ma->uri, "hp:/net") == NULL && strcasestr(ma->uri, "hp:/par") == NULL)
+   if (strcasestr(ma->uri, "hp:") == NULL && strcasestr(ma->uri, "hpfax:") == NULL && strcasestr(ma->uri, "hpaio:") == NULL)
+      return 1;  /* invalid uri */
+
+   if (strcasestr(ma->uri, ":/usb") == NULL && strcasestr(ma->uri, ":/net") == NULL && strcasestr(ma->uri, ":/par") == NULL)
       return 1;  /* invalid uri */
 
    if (strcasestr(ma->uri, "device=") != NULL)
@@ -539,6 +509,7 @@ int System::UsbDiscovery(char *lst, int *cnt)
    return size;
 }
 
+#ifdef HAVE_PPORT
 //System::ParDiscovery
 //! Walk the parallel ports looking for HP products. 
 /*!
@@ -579,6 +550,12 @@ int System::ParDiscovery(char *lst, int *cnt)
 
    return size;
 }
+#else
+int System::ParDiscovery(char *lst, int *cnt)
+{
+   return 0;
+}
+#endif
 
 //System::ProbeDevices
 //!  Perform hp device discovery. Works simultaneously with other open clients.
@@ -705,15 +682,14 @@ int System::SnmpErrorToPml(int snmp_error)
    return err;
 }
 
-int System::SetSnmp(char *ip, int port, char *szoid, int type, unsigned char *buffer, int size, int *pml_result, int *result)
+int System::SetSnmp(char *ip, int port, char *szoid, int type, unsigned char *buffer, unsigned int size, int *pml_result, int *result)
 {
    struct snmp_session session, *ss=NULL;
    struct snmp_pdu *pdu=NULL;
    struct snmp_pdu *response=NULL;
    oid anOID[MAX_OID_LEN];
    size_t anOID_len = MAX_OID_LEN;
-   int len=0;
-   unsigned int i;
+   unsigned int i, len=0;
    uint32_t val;
 
    *result = R_IO_ERROR;
@@ -738,7 +714,7 @@ int System::SetSnmp(char *ip, int port, char *szoid, int type, unsigned char *bu
       case PML_DT_ENUMERATION:
       case PML_DT_SIGNED_INTEGER:
          /* Convert PML big-endian to SNMP little-endian byte stream. */
-         for(i=0, val=0; i<(unsigned int)size && i<sizeof(val); i++)    
+         for(i=0, val=0; i<size && i<sizeof(val); i++)    
             val = ((val << 8) | buffer[i]);
          snmp_pdu_add_variable(pdu, anOID, anOID_len, ASN_INTEGER, (unsigned char *)&val, sizeof(val));
          break;
@@ -773,12 +749,12 @@ bugout:
    return len;
 }
 
-int System::GetSnmp(char *ip, int port, char *szoid, unsigned char *buffer, int size, int *type, int *pml_result, int *result)
+int System::GetSnmp(char *ip, int port, char *szoid, unsigned char *buffer, unsigned int size, int *type, int *pml_result, int *result)
 {
    struct snmp_session session, *ss=NULL;
    struct snmp_pdu *pdu=NULL;
    struct snmp_pdu *response=NULL;
-   int i, len=0;
+   unsigned int i, len=0;
    oid anOID[MAX_OID_LEN];
    size_t anOID_len = MAX_OID_LEN;
    struct variable_list *vars;
@@ -817,7 +793,7 @@ int System::GetSnmp(char *ip, int port, char *szoid, unsigned char *buffer, int
             *type = PML_DT_SIGNED_INTEGER;
 
             /* Convert SNMP little-endian to PML big-endian byte stream. */
-            len = (sizeof(uint32_t) < (unsigned int)size) ? sizeof(uint32_t) : size;
+            len = (sizeof(uint32_t) < size) ? sizeof(uint32_t) : size;
             val = *vars->val.integer;
             for(i=len; i>0; i--)
             {
@@ -826,9 +802,9 @@ int System::GetSnmp(char *ip, int port, char *szoid, unsigned char *buffer, int
             }
 
             /* Remove any in-significant bytes. */
-            for (; tmp[i-1]==0 && i<=len; i++)
+            for (; tmp[i]==0 && i<len; i++)
                ;
-            len -= --i;
+            len -= i;
 
             memcpy(buffer, tmp+i, len);
             break;
@@ -837,7 +813,7 @@ int System::GetSnmp(char *ip, int port, char *szoid, unsigned char *buffer, int
             break;
          case ASN_OCTET_STR:
             *type = PML_DT_STRING;
-            len = (vars->val_len < (unsigned int)size) ? vars->val_len : size;
+            len = (vars->val_len < size) ? vars->val_len : size;
             memcpy(buffer, vars->val.string, len);
             break;
          default:
@@ -860,13 +836,13 @@ bugout:
 
 #else
 
-int System::SetSnmp(char *ip, int port, char *szoid, int type, unsigned char *buffer, int size, int *pml_result, int *result)
+int System::SetSnmp(char *ip, int port, char *szoid, int type, unsigned char *buffer, unsigned int size, int *pml_result, int *result)
 {
    syslog(LOG_ERR, "no JetDirect support enabled\n");
    return 0;
 }
 
-int System::GetSnmp(char *ip, int port, char *szoid, unsigned char *buffer, int size, int *type, int *pml_result, int *result)
+int System::GetSnmp(char *ip, int port, char *szoid, unsigned char *buffer, unsigned int size, int *type, int *pml_result, int *result)
 {
    syslog(LOG_ERR, "no JetDirect support enabled\n");
    return 0;
@@ -1259,9 +1235,7 @@ int System::ParseMsg(char *buf, int len, MsgAttributes *ma)
       if (strcasecmp(key, "device-uri") == 0)
       {
          strncpy(ma->uri, value, sizeof(ma->uri));
-         if (!((strncasecmp(ma->uri, "hp:", 3) == 0) &&
-               (strstr(ma->uri, "?") != NULL) &&
-                  (GeneralizeURI(ma) == 0)))
+         if (GeneralizeURI(ma) != 0)
          {
             syslog(LOG_ERR, "invalid uri:%s\n", ma->uri);
             ret = R_INVALID_URI;
@@ -1487,11 +1461,10 @@ Device *System::NewDevice(MsgAttributes *ma)
    {
       if (pDevice[i] == NULL)
       {
-         if (strcasestr(ma->uri, "hp:/usb") != NULL)
+         if (strcasestr(ma->uri, ":/usb") != NULL)
          {
             if (ma->prt_mode == UNI_MODE)
             {
-//               syslog(LOG_INFO, "using uni-di backend for %s\n", ma->uri);
                pD = new UniUsbDevice(this);
             }
             else
@@ -1502,16 +1475,16 @@ Device *System::NewDevice(MsgAttributes *ma)
                pD->SetFlowCtl(ma->flow_ctl);              /* flow control for mfp mode */
             }
          }
-         else if (strcasestr(ma->uri, "hp:/net") != NULL)
+         else if (strcasestr(ma->uri, ":/net") != NULL)
          {
             pD = new JetDirectDevice(this);
             pD->SetScanPort(ma->scan_port);            /* network scan port selection */ 
          }
-         else if (strcasestr(ma->uri, "hp:/par") !=NULL)
+#ifdef HAVE_PPORT
+         else if (strcasestr(ma->uri, ":/par") !=NULL)
          {
             if (ma->prt_mode == UNI_MODE)
             {
-//               syslog(LOG_INFO, "using uni-di backend for %s\n", ma->uri);
                pD = new UniParDevice(this);
             }
             else
@@ -1522,6 +1495,7 @@ Device *System::NewDevice(MsgAttributes *ma)
                pD->SetFlowCtl(ma->flow_ctl);              /* flow control for mfp mode */
             }
          }
+#endif
          else
          {
             goto bugout;
