@@ -43,6 +43,10 @@
 #include "services.h"
 #include "hpijs.h"
 
+#ifdef HAVE_LIBHPIP
+extern  int hpijsFaxServer (int argc, char **argv);
+#endif
+
 extern int hpijs97();
 
 int bug(const char *fmt, ...)
@@ -300,22 +304,53 @@ int hpijs_set_cb (void *set_cb_data, IjsServerCtx *ctx, IjsJobId job_id,
 int hpijs_get_cb(void *get_cb_data, IjsServerCtx *ctx, IjsJobId job_id, const char *key, char *value_buf, int value_size)
 {
    UXServices *pSS = (UXServices*)get_cb_data;
+   float        fY;
 
    if (!strcmp (key, "PrintableArea"))
    {
+       fY = pSS->pPC->PrintableHeight ();
       /* If duplexing, adjust printable height to 1/2 inch top/bottom margins, except laserjets. */
       if ((pSS->pPC->QueryDuplexMode() != DUPLEXMODE_NONE) && pSS->pPC->RotateImageForBackPage())
-         return snprintf(value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableWidth(), pSS->pPC->PhysicalPageSizeY()-1);
-      else
-         return snprintf(value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableWidth(), pSS->pPC->PrintableHeight());
+      {
+          // User has requested fullbleed printing and printer supports 4-sided fullbleed or
+          // top and bottom margin are equal (0.125"), then
+          // don't need top and bottom margins to be 0.5" each. In other words, if physical page size -
+          // printable height is more than 0.25 inches, adjustment is required for symmetry.
+          // Update - 11/22/05: Not so, the autoduplexer still requires a half inch margin.
+#if 0
+         if ((pSS->pPC->PrintableHeight () + 0.28) < pSS->pPC->PhysicalPageSizeY ())
+         {
+             fY = pSS->pPC->PhysicalPageSizeY () - 1.0;
+         }
+#endif
+         fY = pSS->pPC->PhysicalPageSizeY () - 1.0;
+//         return snprintf(value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableWidth(), pSS->pPC->PhysicalPageSizeY()-1);
+      }
+//      else
+//         return snprintf(value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableWidth(), pSS->pPC->PrintableHeight());
+      return (snprintf (value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableWidth (), fY));
    }
    else if (!strcmp (key, "PrintableTopLeft"))
    {
+       fY = pSS->pPC->PrintableStartY (); 
       /* If duplexing, adjust printable top to 1/2 inch top margin, except laserjets. */
       if ((pSS->pPC->QueryDuplexMode() != DUPLEXMODE_NONE) && pSS->pPC->RotateImageForBackPage())
+      {
+#if 0
+         if ((pSS->pPC->PrintableHeight () + 0.28) < pSS->pPC->PhysicalPageSizeY ())
+         {
+             fY = 0.5;
+         }
+#endif
+         fY = 0.5;
+      }
+      return snprintf (value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableStartX (), fY);
+
+/*
          return snprintf(value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableStartX(), 0.5);
       else
          return snprintf(value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableStartX(), pSS->pPC->PrintableStartY());
+ */
    }
    else if ((!strcmp (key, "Duplex")) || (!strcmp (key, "PS:Duplex")))
    {
@@ -403,7 +438,7 @@ int hpijs_get_client_raster(IjsServerCtx *ctx, char *buf, int size, char white)
    return size;
 }
 
-int main(int argc, char *argv[])
+int main(int argc, char *argv[], char *evenp[])
 {
    UXServices *pSS = NULL;
    IjsServerCtx *ctx = NULL;
@@ -422,6 +457,15 @@ int main(int argc, char *argv[])
       }
    }
 
+#ifdef HAVE_LIBHPIP
+   char *pDev;
+   if ((pDev = getenv ("DEVICE_URI")) &&
+       ((strncmp (pDev, "hpfax:", 6)) == 0))
+   {
+       exit ( hpijsFaxServer (argc, argv));
+   }
+#endif
+
    ctx = ijs_server_init();
    if (ctx == NULL)
    {
@@ -442,7 +486,9 @@ int main(int argc, char *argv[])
 #endif
 
    pSS->pPC = new PrintContext(pSS, 0, 0);
-   if (pSS->pPC->constructor_error > 0)
+
+   /* Ignore JOB_CANCELED. This a bi-di hack that allows the job to continue even if bi-di communication failed. */
+   if (pSS->pPC->constructor_error > 0 && pSS->DisplayStatus != DISPLAY_PRINTING_CANCELED)
    {
       bug("unable to open PrintContext object err=%d\n", pSS->pPC->constructor_error);
       goto BUGOUT;
@@ -450,9 +496,6 @@ int main(int argc, char *argv[])
    if (pSS->pPC->constructor_error < 0)
       bug("WARNING: %s\n", pSS->GetDriverMessage(pSS->pPC->constructor_error));
 
-   /* Turn off any bi-di support. Allow bi-di for printer capabilities only. */
-   pSS->IOMode.bDevID = pSS->IOMode.bStatus = FALSE;
-
 #if 0
    bug("device model=%s\n", pSS->pPC->PrinterModel());
    bug("device class=%s\n",  pSS->pPC->PrintertypeToString(pSS->pPC->SelectedDevice()));
@@ -498,6 +541,10 @@ int main(int argc, char *argv[])
             bug("unable to SetPixelsPerRow width=%d, err=%d\n", pSS->ph.width, ret);
          }
 
+         /* Turn off any bi-di support. Allow bi-di for printer capabilities only. */
+//         pSS->IOMode.bDevID = pSS->IOMode.bStatus = FALSE;
+         pSS->ResetIOMode (FALSE, FALSE);
+
          if (pSS->pJob != NULL)
             delete pSS->pJob;
          pSS->pJob = new Job(pSS->pPC);
